summaryrefslogtreecommitdiffstats
path: root/kiosktool/kioskrun.h
diff options
context:
space:
mode:
Diffstat (limited to 'kiosktool/kioskrun.h')
-rw-r--r--kiosktool/kioskrun.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kiosktool/kioskrun.h b/kiosktool/kioskrun.h
index 54a25a2..4275cb3 100644
--- a/kiosktool/kioskrun.h
+++ b/kiosktool/kioskrun.h
@@ -127,10 +127,10 @@ public:
// Delete directory in test home dir
void deleteDir(const TQString &);
// Open /etc/kderc for writing
KSimpleConfig *openKderc();
- // Install new /etc/kderc
+ // Install new /etc/tderc
bool closeKderc();
// Read information of profile @p profile
@@ -205,7 +205,7 @@ private:
bool m_forceSycocaUpdate;
bool m_isRoot;
- TQString m_kderc;
+ TQString m_tderc;
TQString m_localKderc;
KSimpleConfig *m_localKdercConfig;
};
@@ -127,10 +127,10 @@ public:
// Delete directory in test home dir
void deleteDir(const TQString &);
- // Open /etc/kderc for writing
+ // Open /etc/tderc for writing
KSimpleConfig *openKderc();